@@ -31,7 +31,6 @@
 import os
 import sys
 sys.path.insert(0, os.path.abspath('../../src'))
-sys.path.insert(0, os.path.abspath('../../src/trovares_connector'))
 print(f"Sys.path: {sys.path}")
 
 
@@ -42,7 +41,7 @@ copyright = '2022, Trovares, Inc.'
 author = 'trovares.com'
 
 # The full version, including alpha/beta/rc tags
-release = '1.2.0'
+release = '1.3.0'
 
 # -- General configuration ---------------------------------------------------
 
@@ -52,8 +51,9 @@ extensions = [
   'sphinx.ext.autosummary',
   'sphinx.ext.napoleon',
   'sphinx.ext.mathjax',
+  'sphinx.ext.viewcode',
   'myst_nb',
-  #'IPython.sphinxext.ipython_console_highlighting',
+  'sphinx_copybutton',
 ]
 mathjax_path = 'https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.1/MathJax.js?config=TeX-AMS-MML_HTMLorMML'
 
@@ -112,9 +112,10 @@ html_theme_options = {
   'path_to_docs' : 'docs/source',
   'repository_branch' : 'main',
   #"use_edit_page_button": True,
-  "use_issues_button": True,
-  "use_repository_button": True,
-  "use_download_button": True,
+  'use_issues_button': True,
+  'use_repository_button': True,
+  'use_download_button': True,
+  'show_toc_level': 2,
 }
 
 # Left sidebar title
